|Build Status| |Documentation Status| |Coverage Status| |Conda Version|
|Conda Installation| |Conda Downloads|

bmi-tester
==========

Test Python implementations of the Basic Model Interface.

Links
-----

-  `Source code <http://github.com/csdms/bmi-tester>`__: The
   *bmi-tester* source code repository.
-  `Documentation <http://bmi-tester.readthedocs.io/>`__: User
   documentation for *bmi-tester*
-  `Get <http://bmi-tester.readthedocs.io/en/latest/getting.html>`__:
   Installation instructions

.. |Build Status| image:: https://travis-ci.org/csdms/bmi-tester.svg?branch=master
   :target: https://travis-ci.org/csdms/bmi-tester
.. |Documentation Status| image:: https://readthedocs.org/projects/bmi-tester/badge/?version=latest
   :target: http://bmi-tester.readthedocs.io/en/latest/?badge=latest
.. |Coverage Status| image:: https://coveralls.io/repos/github/csdms/bmi-tester/badge.svg?branch=master
   :target: https://coveralls.io/github/csdms/bmi-tester?branch=master
.. |Conda Version| image:: https://anaconda.org/conda-forge/bmi-tester/badges/version.svg
   :target: https://anaconda.org/conda-forge/bmi-tester
.. |Conda Installation| image:: https://anaconda.org/conda-forge/bmi-tester/badges/installer/conda.svg
   :target: https://conda.anaconda.org/conda-forge
.. |Conda Downloads| image:: https://anaconda.org/conda-forge/bmi-tester/badges/downloads.svg
   :target: https://anaconda.org/conda-forge/bmi-tester
